@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 9137 2013-05-10 05:04:22Z Yachu $
+# $Id: views.py 10198 2017-08-19 16:19:02Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Yachu $
-# $Date: 2013-05-10 13:04:22 +0800 (週五, 10 五月 2013) $
-# $Revision: 9137 $
+# $Author: David $
+# $Date: 2017-08-20 00:19:02 +0800 (Sun, 20 Aug 2017) $
+# $Revision: 10198 $
 
 import re
 from urlparse import urljoin
@@ -367,7 +367,7 @@ def handleSNS(request):
     # Get the message type header.
     # String messagetype = request.getHeader("x-amz-sns-message-type");
     # If message doesn't have the message type header, don't process it.
-    postData = request._get_raw_post_data()
+    postData = request.body
 
     try:
         amazonLogger.info("RECEIVED: %s" % str(postData))
